ConfigInfo class

Constructors

ConfigInfo(String baseUrl, String background, String mainColor, String mainTextColor, String btnTextColor, String lang, int livenessVersion, {String? mrz, String? faceDataBase64String, bool requireQRCode = false, String documentType = 'FRONT', String? customer, int nfcTimeoutInSeconds = 180, bool skipConfirm = false, bool allowMRZRescanOnNFCMismatch = true, bool strictLiveness = false})

Properties

allowMRZRescanOnNFCMismatch ↔ bool
getter/setter pair
background ↔ String
getter/setter pair
baseUrl ↔ String
getter/setter pair
btnTextColor ↔ String
getter/setter pair
customer ↔ String?
Customer id used to pull a customer-specific language pack.
getter/setter pair
documentType ↔ String
One of: FRONT, BACK, PORTRAIT, PASSPORT (maps to KalapaSDKMediaType).
getter/setter pair
faceDataBase64String ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lang ↔ String
getter/setter pair
livenessVersion ↔ int
getter/setter pair
mainColor ↔ String
getter/setter pair
mainTextColor ↔ String
getter/setter pair
mrz ↔ String?
getter/setter pair
nfcTimeoutInSeconds ↔ int
NFC read timeout in seconds.
getter/setter pair
requireQRCode ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipConfirm ↔ bool
getter/setter pair
strictLiveness ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited