ConfigAppInfo class

Constructors

ConfigAppInfo({String baseUrl = 'https://ekyc-sdk.kalapa.vn', String token = "", String mrz = "", String mainColor = '#2081AF', String mainTextColor = '#000000', String btnTextColor = '#FFFFFF', String backgroundColor = '#FFFFFF', bool captureEnabled = true, bool nfcEnabled = true, String lang = 'vi-VN', int livenessVersion = 0, List<String> acceptedDocuments = const ["CMND9", "CMND12", "CCCD", "EID"], int faceMatchingThreshold = 50, bool verifyCheck = true, bool fraudCheck = true, bool strictQualityCheck = true, bool cardSidesMatch = true})
ConfigAppInfo.fromJson(String source)
factory
ConfigAppInfo.fromMap(Map<String, dynamic> map)
factory

Properties

acceptedDocuments ↔ List<String>
getter/setter pair
backgroundColor ↔ String
getter/setter pair
baseUrl ↔ String
getter/setter pair
btnTextColor ↔ String
getter/setter pair
captureEnabled ↔ bool
getter/setter pair
cardSidesMatch ↔ bool
getter/setter pair
faceMatchingThreshold ↔ int
getter/setter pair
fraudCheck ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lang ↔ String
getter/setter pair
livenessVersion ↔ int
getter/setter pair
mainColor ↔ String
getter/setter pair
mainTextColor ↔ String
getter/setter pair
mrz ↔ String
getter/setter pair
nfcEnabled ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strictQualityCheck ↔ bool
getter/setter pair
token ↔ String
getter/setter pair
uri → String
no setter
verifyCheck ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited